"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const name_generator_1 = require("../name-generator");
const wordsets_1 = require("../wordsets");
describe('Generate a default random name', () => {
    test('Should not be null', () => {
        expect(name_generator_1.generateRandomName()).not.toBeNull();
    });
    test('Should not be an empty string', () => {
        expect(name_generator_1.generateRandomName()).not.toBe('');
    });
});
describe('Generate a name from included sets', () => {
    test('Generated word should be from the adjectives set', () => {
        const word1Options = { includeAdjectives: true };
        const name = name_generator_1.generateRandomName([word1Options]);
        expect(wordsets_1.adjectives.includes(name)).toBeTruthy();
    });
    test('Generated word should be from the animals or mythical animals set', () => {
        const word1Options = { includeAnimals: true, includeMythicalAnimals: true };
        const name = name_generator_1.generateRandomName([word1Options]);
        expect(wordsets_1.animals.includes(name) || wordsets_1.mythicalAnimals.includes(name)).toBeTruthy();
    });
    test('Check words in result', () => {
        const word1Options = { includeColors: true };
        const word2Options = { includeAdjectives: true };
        const name = name_generator_1.generateRandomName([word1Options, word2Options]);
        const words = name.split(' ');
        expect(wordsets_1.colors.includes(words[0])).toBeTruthy();
        expect(wordsets_1.adjectives.includes(words[1])).toBeTruthy();
    });
    test('Check last word in combined arrays', () => {
        const word1Options = { includeColors: true };
        const word2Options = { includeAnimals: true, includeMythicalAnimals: true };
        const name = name_generator_1.generateRandomName([word2Options, word1Options]);
        const words = name.split(' ');
        expect(wordsets_1.colors.includes(words[words.length - 1])).toBeTruthy();
    });
});
describe('Generate a name from custom sets', () => {
    const customSetA = ['A1', 'A2', 'A3', 'A4', 'A5'];
    const customSetB = ['B1', 'B2', 'B3', 'B4', 'B5'];
    test('Generated word should be two characters long', () => {
        const word1Options = { customWordSet: customSetA };
        const name = name_generator_1.generateRandomName([word1Options]);
        expect(name.length == 2);
    });
    test('Check included words from custom arrays', () => {
        const word1Options = { customWordSet: customSetA };
        const word2Options = { customWordSet: customSetB };
        const name = name_generator_1.generateRandomName([word1Options, word2Options]);
        const words = name.split(' ');
        expect(customSetA.includes(words[0])).toBeTruthy();
        expect(customSetB.includes(words[1])).toBeTruthy();
    });
    test('Check included words in combined arrays', () => {
        const word1Options = { customWordSet: customSetA };
        const word2Options = { includeAnimals: true, includeMythicalAnimals: true };
        const word3Options = { customWordSet: customSetB };
        const name = name_generator_1.generateRandomName([word1Options, word2Options, word3Options]);
        const words = name.split(' ');
        const midPart = name.substring(3, name.length - 3);
        expect(customSetA.includes(words[0])).toBeTruthy();
        expect(customSetB.includes(words[words.length - 1])).toBeTruthy();
        expect(wordsets_1.animals.includes(midPart) || wordsets_1.mythicalAnimals.includes(midPart)).toBeTruthy();
    });
});
